require 'test/unit'
require 'fluent/log'
require 'fluent/test'
require 'fluent/plugin/out_upsolver'

class UpsolverOutputTest < Test::Unit::TestCase
  include Fluent

  setup do
    Fluent::Test.setup
  end

  def create_driver(conf = '')
    Test::BufferedOutputTestDriver.new(UpsolverOutput).configure(conf, true)
  end

  sub_test_case 'configure' do
    test 'url not exists' do
      conf = ''
      assert_raises(ConfigError) { create_driver(conf) }
    end
    test 'url exist' do
      conf = "endpoint_url http://localhost"
      assert_nothing_raised { create_driver(conf) }
    end
  end

  sub_test_case 'output' do
    def emit(conf, msg)
      d = create_driver(conf)
      d.emit({'foo' => 'bar', 'message' => msg}, Fluent::Engine.now)
      d.emit({'foo' => 'bar2', 'message' => msg}, Fluent::Engine.now)
      d.run
    end
    test 'execute output' do
      conf = "endpoint_url http://localhost:12341"
      msg  = "2015/02/10T01:10:20.123456 INFO GET /ping"
      es   = emit(conf, msg)
      # Currently not asserting, will assert once we want to.
    end
  end
end
